@@ -42,9 +42,9 @@ class IntrepidType:
         Convert the DataType to a dictionary representation.
         """
         if self.is_array():
-            return {"type": f"array<{self.base_type.to_dict()}>" }
+            return {"data": f"array<{self.base_type.to_flat_dict()}>" }
         else:
-            return {"type": self.base_type.to_dict()}
+            return self.base_type.to_dict()
 
     @classmethod
     def from_dict(cls, data):
@@ -107,6 +107,9 @@ class Type(Enum):
         else:
             return {"data": self.name.lower()}
 
+    def to_flat_dict(self):
+        return self.name.lower()
+
 
     def __str__(self):
         return self.name.lower()
